StarCityGames.com - World's Largest Magic: The Gathering Store!

- Dec 09, 2015 10:59:00 EST
- Booster Boxes • Booster Cases
  Bundles • Complete Sets
  SET-OF-5 Intro Packs
  Fat Packs & More!
  PREORDER TODAY
  Ships January 22nd
- $24.99

- 1
- 2
- 3
- 4
- 5
- 6
- 7
- 8
- 9

# PREMIUM

## subscribe now!

Ari Lax

Lessons From The Sidelines At #SCGDEN

12/08

#Premium #Standard #SCGINVI

Pro Tour Champion Ari Lax watched the whole event last weekend, and he has pro-level commentary (and hilarity) to enlighten you before the big #SCGINVI and #SCGPC!

Shaun McLaren

What Will Be Banned In Modern?

12/08

#Premium #Modern

Pro Tour Champ Shaun McLaren knows a thing or two about the Modern format. That's why he's advocating for different banning announcement times and discussing everything else he expects to hear about the format come January!

Gerry Thompson

Video: Mardu Green In Standard

12/08

#Premium #Standard #Video #SCGINVI

The four-color mishmash is all over the place, and GerryT is climbing onboard yet another new one! #SCGINVI will be filled to the brim with these sorts of strategies. Will you be prepared?

Patrick Chapin

The Return Of Jeskai And Grixis

12/07

#Premium #Standard #SCGINVI

If followed the pro metagamers into last week's Open, you weren't surprised by the results. Patrick Chapin reviews this week's big players and what you can do to prey on them at the #SCGINVI!

Chas Andres

Buying Standard For The Spring

12/07

#Premium #Standard #Finance

Though there's always fluctuation in Magic's marketplace, there are some universal truths: one of them is that winter and Standard do not get along. Let Chas show you how you stand to benefit and save some cash during the holiday Magic lull!

Todd Anderson & Brian Braun-Duin

Todd VS. BBD: Jeskai Twin VS. G/W Hate Bears

12/07

#Premium #Modern #Video #Versus #SCGINVI

The #SCGINVI features some great Modern action this weekend, and who knows which will do better among the fair decks and their unfair counterparts? Todd and BBD are on the case in this week's latest VS Video effort!

Brian Kibler

Modern Deck Selection For #SCGINVI

12/04

#Premium #Modern #SCGINVI #SCGDEN

#SCGDEN may have a $5,000 Modern Premier IQ, but The Dragonmaster is already looking to add an #SCGINVI title to his two Pro Tour Championships! See the creatures he wants to attack the format with come Invitational time!

Sam Black

Video: W/B Warriors In Standard

12/04

#Premium #Standard #Video #SCGDEN

It took some time, but the Warriors are finally out in full Standard swing! Check this deck out to see if it's your best shot for conquering #SCGDEN this weekend!

Todd Anderson & Brian Braun-Duin

Todd VS. BBD: Jeskai Mentor VS. G/W Megamorph

12/04

#Premium #Standard #Video #Versus #SCGDEN

These two Standard juggernauts are both worried about staying on top at #SCGDEN. Can they do it, or will something else be the new deck to beat? Todd and BBD investigate!

Brad Nelson

The #SCGPC Approaches!

12/03

#Premium #Standard #SCGPC #SCGDEN

Defending #SCGPC Champ Brad Nelson has some horses he's rooting for in the race to the big end of the year finish! So in helping him prep for #SCGDEN, what has he learned about Standard? Let's find out!

Tom Ross

Weathering The Storm

12/03

#Premium #Legacy #SCGDEN

Storm has returned to being one of the most consistently difficult decks to conquer in Legacy lately. What decks beat it? What cards bother it? How do you approach it at #SCGDEN's $5,000 Legacy Premier IQ? The Boss has the answers!

Todd Anderson

Video: Esper Dragons In Standard

12/03

#Premium #Standard #Video #SCGDEN

Esper Dragons is great when it's great, but when it isn't...not so much. So which will it be at #SCGDEN? We ask perhaps the greatest Open Series player of all-time, Todd Anderson, to figure it out for us!

Ari Lax

Video: Infect In Modern

12/03

#Premium #Modern #Video #SCGDEN

Pro Tour Champion Ari Lax is always on top of Modern's changing landscape. Does he think Infect is the way to go at #SCGDEN's $5,000 Premier IQ? Find out in this new video!

# SELECT

## always free!

Daily Digest: Modern Mayhem!

Gerry Thompson

12/08

#SCGINVI will be largely dictated by the Modern game the players bring to the table, and this deck has a great chance at crushing out of nowhere! Check out GerryT's latest Daily Digest entry!

#Select #Modern #SCGINVI

The Continuing Saga Of Mardu Guy

Mark Nestico

12/08

Mark Nestico has taken up the title. #SCGINVI will probably have an inexplicably iffy Mardu deck in the top 8, and Mark Nestico is ready to embrace that reality. See his analysis on the unsung archetype here!

#Select #Standard #SCGINVI

Eldrazi Ascendancy!

Matt Higgs

12/08

The Ascendancy cycle is largely unused these days in Standard, but Matt Higgs knows just how powerful they can be! See him grab the cycle for another go to make some nasty #SCGINVI-ready combos!

#Select #Standard #SCGINVI

Dear Azami: Ten Tweaks

Jess Stirba

12/08

Jess is going hard on brevity this week with one of the most underrated tribes in Commander (and Magic)! Get your scry triggers ready and have your knowledge on tap, because it's time to free the Sphinxes!

#Select #CMDR #DearAzami

Daily Digest: Joe Drawsett

Gerry Thompson

12/07

GerryT pays tribute to one of the great control players on the Open Series today. But be warned! If you plan to sleeve this one up for #SCGINVI, you'd better have your practice in!

#Select #Standard #SCGINVI

Is "Good Enough" Good Enough?

Anthony Lowry

12/07

In following and playing Magic, we're constantly seeing others succeed and fail. The pressure and expectations we put on ourselves and others is always there, but is it fair? Anthony Lowry ponders the importance of personal preference when it comes to competitive Magic.

#Select #Fundamentals

Block Commander!

Abe Sargent

12/07

Is there anyone better at spicing up stale casual formats than Abe Sargent? If you need a kick in your Commander tables, try out Abe's latest format project!

#Select #CMDR

Daily Digest: The Most Underplayed Archetype In Modern

Gerry Thompson

12/04

#SCGDEN may show us at the next big thing at its $5,000 Modern Premier IQ! Based on its matchups and its gameplan, don't be surprised if this one starts up the format's ladder fast!

#Select #Modern #SCGDEN

BBD VS. The Boss: Esper Control VS. Atarka Red

Brian Braun-Duin & Tom Ross

12/04

Control. Aggro. There can only be one. Tom and BBD are at each other's throats to find out who will prevail in the battle of classic Magic paradigm as we approach #SCGDEN!

#Select #Standard #Video #Versus #SCGDEN

W/B Tokens In Modern

Joshua Cho

12/04

Guess who's back on the Pro Tour? Josh Cho accomplished the feat with a Modern deck that he thinks is highly underrated! He's here to provide you a complete guide to his Modern strategy entering #SCGDEN's $5,000 Premier IQ!

#Select #Modern #SCGDEN

All Of My Blue Decks (And Then Some)

Adrian Sullivan

12/04

Adrian has back to back event weekends, and this Standard is proving really difficult to master! That's why he's exploring the closest things to his favorite deck of last year! Learn the blue ropes of the format for #SCGDEN!

#Select #Standard #SCGDEN

Are You Experienced?

Bennie Smith

12/04

The great Bennie Smith likes experience counters enough to build a deck that amasses as many as humanly possible! See his build and his thoughts on MTGO's sweet new Legendary Cube!

#Select #CMDR #Cube

Daily Digest: Endless Fun

Gerry Thompson

12/03

The amount of Eldrazi tech that's available to us in only now becoming apparent. And we're not just talking about Standard! Try to process this deck before #SCGDEN's $5,000 Modern Premier IQ!

#Select #Modern #SCGDEN

Fifteen Rounds

Jim Davis

12/03

#SCGNJ was one for the Legacy books, and Jim Davis had an up and down event! Read about his experience in full and his thoughts on the best deck choice for the $5,000 Legacy Premier IQ at #SCGDEN!

#Select #Legacy #SCGNJ #SCGDEN

The World's Longest Brainstorm

Ross Merriam

12/03

Want to see the thought process behind a pro Magic player? How about a pro Magic player wielding a deck as crazy difficult as Storm? Ross Merriam shows you what you're up against if you sit across from Ad Nauseams and Lion's Eye Diamonds at #SCGDEN's $5,000 Premier IQ!

#Select #Legacy #SCGDEN

Modern Selection

Chris Lansdell

12/03

Chris Lansdell is hard at work on getting his choices locked in for his run at the #SCGINVI title in Vegas! He's decided to play unfair Magic, and today, he's breaking down the combo decks for #SCGDEN's $5,000 Modern Premier IQ!

#Select #Modern #SCGDEN
ORGANIZED PLAY

- THIS Friday, December 11
- INVITATIONAL Las Vegas
- Invitational Qualifiers
- Somerville, NJ - The Only Game in Town
- THIS Saturday, December 12
- INVITATIONAL Las Vegas
- 5K Premier Invitational Qualifiers
- Chicago, IL - Pastimes
- East Windsor, CT - Ice Imports
- 1K Super Invitational Qualifiers
- Athens, AL - Static Age Games
- Invitational Qualifiers
- Athens, GA - Card Advantage
- Aurora, CO - All C's Gaming Arena
- Cayce, SC - Ready to Play Trading Cards
- Crestview, FL - GameMasters Guild
- Four Oaks, NC - Hobby Invasion
- Glen Burnie, MD - Games and Stuff
- Granite Falls, NC - Warlords Games
- Hatboro, PA - Stomping Grounds
- New Philadelphia, OH - MAD Bros
- Prairieville, LA - Gamers Paradise
- River Falls, WI - Game Quest
- Roanoke, VA - Star City Game Center
- San Antonio,TX - Dragon's Lair Comics and Fantasy
- Springfield, MO - Meta-Games Unlimited
- Temple, TX - The Card House
- Warner Robin, GA - Heroes and Villains
- GPT (IQ Prizes)
- Gatlinburg, TN - Gamers Link
- THIS Sunday, December 13
- INVITATIONAL Las Vegas
- 1K Super Invitational Qualifiers
- Columbia, MO - Magelings Games
- East Windsor, CT - Ice Imports
- Invitational Qualifiers
- Cary, NC - East Coast Gaming
- Dalton, GA - The Battlegrounds Games and Comics
- East Windsor, NJ - Gamer's Realm Hobby
- Falls Church, VA - Victory Comics
- Guatemala City, GT - Master Games
- Kingsport, TN - Mulligan's Gaming
- Lexington, KY - Legendary Games
- Lutherville/Timonium, MD - Titan Games and Hobbies
- New Holland, PA - Six Feet Under Games
- Roanoke, VA - Star City Game Center

- Tuesday, December 15
- Invitational Qualifiers
- Brooklyn, NY - Kings Games
- Thursday, December 17
- Invitational Qualifiers
- East Windsor, NJ - Gamer's Realm Hobby
- Friday, December 18
- Invitational Qualifiers
- Bronx, NY - The Lair
- Saturday, December 19
- 5K Premier Invitational Qualifiers
- Lansing, MI - Pastimes
- 1K Super Invitational Qualifiers
- Brooklyn, NY - Kings Games
- Indian Trail, NC - Be There Games
- San Diego, CA - San Diego Games and Comics
- Invitational Qualifiers
- Aurora, CO - All C's Gaming Arena
- Burnsville, MN - Legion Games
- Gaithersburg, MD - Play More Games
- Lexington, KY - Legendary Games
- Lutherville/Timonium, MD - Titan Games and Hobbies
- Mountain Grove, MO - Grove Gamers Guild
- West Hartford, CT - Voltage Gaming
- Sunday, December 20
- Invitational Qualifiers
- Boonton, NJ - Highlander Games & Comics
- Bristol, TN - MWO Games
- Columbus, OH - Comic Town
- Fountain, CO - J&J Games N Hobbies
- Glassboro, NJ - The Comic Book Store
- Granite Falls, NC - Warlords Games
- Lafayette, IN - Legendary Games
- San Salvador, SV - Naruto Ramen Cards and Games
- Springfield, VA - Curio Cavern
- West Hartford, CT - Voltage Gaming

STARCITYGAMES.COM® EVENTS

- Dec 11 -13: INVITATIONAL Las Vegas

ELITE QUALIFIERS

- THIS WEEK: See all Open Trials

EVENT FINDER

- Complete SCG Schedule - Coverage Archive

1 | JONATHAN N MORAWSKI | 275
2 | KEVIN JONES | 269
3 | ROSS MERRIAM | 257
4 | HUNTER NANCE | 251
5 | JOE LOSSETT | 250
6 | RUDY BRIKSZA | 244
7 | TODD ANDERSON | 243
8 | TOM ROSS | 237
9 | ERIC C HAWKINS | 235
10 | LOGAN G MIZE | 229
11 | CHRIS ANDERSEN | 218
12 | CALEB W SCHERER | 212
13 | JIM I DAVIS | 203
14 | MATTHEW M TICKAL | 203
15 | ANDREW JESSUP | 198
16 | DANNY JESSUP | 198

NEWS

- 12/4 Game Night in December, January and February!
- 12/4 SCG Season One Regionals on February 6!
- 11/13 Ryan Hoffman’s Judge Token!
- 11/6 Game Night in November, December and January!
- 10/22 Take Our IQ Player Survey!
- 10/19 SCGMobile® App Sunsets October 31st
- 10/5 Fall 2015 Creature Collection Products!
- 10/2 Get Alex Bastecki's Invitational Winner's Token!
- 10/2 Game Night in October, November, and December!
- 9/28 Battle for Zendikarrot Playmat Now on Sale!
- 9/21 Limited-Edition Brian Kibler “Wedding” Playmat!
- 9/14 Alex Bastecki’s Invitational Winner Token!
- View All News Items - Submit Magic News

DECKLISTS

- 12/05 SCG Open Denver, US
- 11/29 Invi Qualifier Columbus, US
- 11/29 SCG Premier IQ Somerset, US
- 11/28 Invi Qualifier Duluth, US
- 11/24 Invi Qualifier Brooklyn, US
- 11/22 SCG Super IQ San Diego, US
- 11/22 Invi Qualifier Charlotte, US
- 11/22 Invi Qualifier Dalton, US
- 11/22 Invi Qualifier Guatemala, GT
- 11/21 Invi Qualifier Arvada, US
- 11/21 Invi Qualifier Nanuet, US
- 11/21 Invi Qualifier Owensboro, US
- 11/21 Grand Prix Kobe, JP
- 11/21 SCG Open Kansas City, US
- 11/20 Invi Qualifier Bronx, US
- 11/19 Invi Qualifier Hartsdale, US
- 11/15 Invi Qualifier Conroe, US
- 11/15 Invi Qualifier Kent, US
- 11/15 SCG Super IQ Vacaville, US
- 11/15 Invi Qualifier Cockeysville, US

View More Standard Decks - Search Decklists

- 12/06 SCG Premier IQ Denver, US
- 11/29 SCG Premier IQ Somerset, US
- 11/29 SCG Premier IQ Somerset,
- 11/28 Invi Qualifier Bloomington, US
- 11/28 Invi Qualifier Burnsville, US
- 11/22 Invi Qualifier Eau Claire, US
- 11/22 Invi Qualifier West Hartford, US
- 11/22 Invi Qualifier Scarborough, US
- 11/22 Invi Qualifier Baton Rouge, US
- 11/22 Invi Qualifier Decatur, US
- 11/22 SCG Premier IQ Kansas City, US
- 11/21 Invi Qualifier Kingsport, US
- 11/21 Invi Qualifier Cary, US
- 11/21 Invi Qualifier Decatur, US
- 11/21 Invi Qualifier Dover, US
- 11/21 Grand Prix Pittsburgh, US
- 11/20 Invi Qualifier Newington, US
- 11/19 Invi Qualifier East Windsor, US
- 11/17 Invi Qualifier Brooklyn, US
- 11/15 Invi Qualifier Falls Church, US

View More Modern Decks - Search Decklists

- 12/06 SCG Premier IQ Denver, US
- 11/28 Invi Qualifier Findlay, US
- 11/28 SCG Open Somerset, US
- 11/27 Invi Qualifier Somerville, US
- 11/22 SCG Premier IQ Kansas City, US
- 11/21 Invi Qualifier Acton, US
- 11/08 Invi Qualifier Roanoke, US
- 11/08 SCG Premier IQ Philadelphia, US
- 11/07 Invi Qualifier East Windsor, US
- 11/07 Grand Prix Tacoma, US
- 11/01 Invi Qualifier Shakopee, US
- 11/01 Invi Qualifier East Windsor, US
- 11/01 SCG Premier IQ Dallas, US
- 10/30 Invi Qualifier Newington, US
- 10/24 SCG Open St. Louis, US
- 10/11 Invi Qualifier Aurora, US
- 10/11 SCG Premier IQ Atlanta, US
- 10/10 Invi Qualifier Columbia, US
- 10/04 Invi Qualifier Eau Claire, US
- 10/04 SCG Super IQ Columbia, US

View More Legacy Decks - Search Decklists
SOCIAL

StarCityGames.com® on Facebook

StarCityGames.com® on Twitter

Join the conversation

StarCityGames.com® on YouTube

Watch the best in Magic Video

WEEKLY NEWSLETTER

Exclusive Deals & Content Every Week